==> blesta-5.10.2.zip: blesta/components/modules/direct_admin/language/uk_ua/direct_admin.php <==
<?php
/**
 * Direct Admin
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DirectAdmin.tab_client_actions.field_direct_admin_password'] = 'Пароль';
$lang['DirectAdmin.tab_client_stats.no_results'] = 'Статистична інформація наразі недоступна.';
$lang['DirectAdmin.tab_client_stats.info_heading.value'] = 'Значення';
$lang['DirectAdmin.tab_client_stats.info_heading.field'] = 'Поле';
$lang['DirectAdmin.tab_client_stats.info_title'] = 'Інформація';
$lang['DirectAdmin.tab_client_stats'] = 'Статистика';
$lang['DirectAdmin.edit_row.add_btn'] = 'Сервер редагування';
$lang['DirectAdmin.edit_row.notes_title'] = 'Примітки';
$lang['DirectAdmin.edit_row.remove_name_server'] = 'Видалити';
$lang['DirectAdmin.edit_row.name_server_host_col'] = 'Ім\'я хоста';
$lang['DirectAdmin.edit_row.name_server_col'] = 'Сервер імен';
$lang['DirectAdmin.edit_row.name_server_btn'] = 'Додати додатковий сервер імен';
$lang['DirectAdmin.edit_row.name_servers_title'] = 'Сервери імен';
$lang['DirectAdmin.edit_row.basic_title'] = 'Основні налаштування';
$lang['DirectAdmin.edit_row.box_title'] = 'Редагування сервера DirectAdmin';
$lang['DirectAdmin.add_row.add_btn'] = 'Додати сервер';
$lang['DirectAdmin.add_row.notes_title'] = 'Примітки';
$lang['DirectAdmin.add_row.remove_name_server'] = 'Видалити';
$lang['DirectAdmin.add_row.name_server_host_col'] = 'Ім\'я хоста';
$lang['DirectAdmin.add_row.name_server_col'] = 'Сервер імен';
$lang['DirectAdmin.add_row.name_server_btn'] = 'Додати додатковий сервер імен';
$lang['DirectAdmin.add_row.name_servers_title'] = 'Сервери імен';
$lang['DirectAdmin.add_row.basic_title'] = 'Основні налаштування';
$lang['DirectAdmin.add_row.box_title'] = 'Додати сервер DirectAdmin';
$lang['DirectAdmin.row_meta.name_server'] = 'Сервер імен %1$s';
$lang['DirectAdmin.row_meta.account_limit'] = 'Ліміт рахунку';
$lang['DirectAdmin.row_meta.use_ssl'] = 'Використовуйте SSL при підключенні до API (рекомендовано)';
$lang['DirectAdmin.row_meta.password'] = 'Пароль';
$lang['DirectAdmin.row_meta.user_name'] = 'Ім\'я користувача';
$lang['DirectAdmin.row_meta.default_port'] = '2222';
$lang['DirectAdmin.row_meta.port'] = 'Порт';
$lang['DirectAdmin.row_meta.host_name'] = 'Ім\'я хоста';
$lang['DirectAdmin.row_meta.server_name'] = 'Мітка сервера';
$lang['DirectAdmin.manage.module_groups.confirm_delete'] = 'Ви впевнені, що хочете видалити цю групу серверів?';
$lang['DirectAdmin.manage.module_rows.confirm_delete'] = 'Ви впевнені, що хочете видалити цей сервер?';
$lang['DirectAdmin.manage.module_groups.delete'] = 'Видалити';
$lang['DirectAdmin.manage.module_rows.delete'] = 'Видалити';
$lang['DirectAdmin.manage.module_groups.edit'] = 'Редагувати';
$lang['DirectAdmin.manage.module_rows.edit'] = 'Редагувати';
$lang['DirectAdmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['DirectAdmin.manage.module_groups_heading.options'] = 'Параметри';
$lang['DirectAdmin.manage.module_groups_heading.servers'] = 'Кількість серверів';
$lang['DirectAdmin.manage.module_groups_heading.name'] = 'Назва групи';
$lang['DirectAdmin.manage.module_rows_heading.options'] = 'Параметри';
$lang['DirectAdmin.manage.module_rows_heading.accounts'] = 'Рахунки';
$lang['DirectAdmin.manage.module_rows_heading.host_name'] = 'Ім\'я хоста';
$lang['DirectAdmin.manage.module_rows_heading.name'] = 'Мітка сервера';
$lang['DirectAdmin.manage.module_groups_title'] = 'Групи серверів';
$lang['DirectAdmin.manage.module_rows_title'] = 'Сервери';
$lang['DirectAdmin.add_module_group'] = 'Додати групу серверів';
$lang['DirectAdmin.add_module_row'] = 'Додати сервер';
$lang['DirectAdmin.package_fields.ip_assign'] = 'Призначити';
$lang['DirectAdmin.package_fields.ip_shared'] = 'Спільне';
$lang['DirectAdmin.package_fields.ip'] = 'IP-адреса';
$lang['DirectAdmin.package_fields.package'] = 'Пакет DirectAdmin';
$lang['DirectAdmin.package_fields.type_reseller'] = 'Посередник';
$lang['DirectAdmin.package_fields.type_user'] = 'Користувач';
$lang['DirectAdmin.package_fields.type'] = 'Тип рахунку';
$lang['DirectAdmin.service_info.option_login'] = 'Увійдіть в систему';
$lang['DirectAdmin.service_info.options'] = 'Параметри';
$lang['DirectAdmin.service_info.server'] = 'Сервер';
$lang['DirectAdmin.service_info.password'] = 'Пароль';
$lang['DirectAdmin.service_info.username'] = 'Ім\'я користувача';
$lang['DirectAdmin.tab_client_actions.text_generate_password'] = 'Згенерувати пароль';
$lang['DirectAdmin.tab_client_actions.field_password_submit'] = 'Оновити пароль';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_confirm_password'] = 'Підтвердити пароль';
$lang['DirectAdmin.tab_client_actions.change_password'] = 'Змінити пароль';
$lang['DirectAdmin.service_field.text_generate_password'] = 'Згенерувати пароль';
$lang['DirectAdmin.service_field.email'] = 'Електронна пошта';
$lang['DirectAdmin.service_field.password'] = 'Пароль';
$lang['DirectAdmin.service_field.username'] = 'Ім\'я користувача';
$lang['DirectAdmin.service_field.domain'] = 'Домен';
$lang['DirectAdmin.server_groups.no_results'] = 'Груп серверів не існує.';
$lang['DirectAdmin.servers.no_results'] = 'Серверів немає.';
$lang['DirectAdmin.order_options.roundrobin'] = 'Рівномірний розподіл між серверами';
$lang['DirectAdmin.order_options.first'] = 'Перший неповний сервер';
$lang['DirectAdmin.tab_client_actions'] = 'Дії';
$lang['DirectAdmin.tab_stats'] = 'Статистика';
$lang['DirectAdmin.module_group'] = 'Група серверів';
$lang['DirectAdmin.module_row_plural'] = 'Сервери';
$lang['DirectAdmin.module_row'] = 'Сервер';
$lang['DirectAdmin.description'] = 'DirectAdmin - це графічна веб-панель керування хостингом, призначена для полегшення адміністрування веб-сайтів.';
$lang['DirectAdmin.!error.change_package.type'] = 'Модуль не підтримує перемикання між пакетами користувача та реселера.';
$lang['DirectAdmin.!error.direct_admin_email.format'] = 'Будь ласка, введіть дійсну адресу електронної пошти.';
$lang['DirectAdmin.!error.direct_admin_password.matches'] = 'Пароль і Підтвердити пароль не збігаються.';
$lang['DirectAdmin.!error.direct_admin_password.format'] = 'Переконайтеся, що пароль містить наступне: Щонайменше 12 символів, щонайменше 1 символ верхнього регістру A-Z, щонайменше 1 символ нижнього регістру a-z, щонайменше 1 цифру 0-9 та щонайменше 1 спеціальний символ з набору: !"#$%&\'()*+,-./:;<=>?@[]^_` {|}';
$lang['DirectAdmin.!error.direct_admin_username.length'] = 'Ім\'я користувача повинно мати довжину від 4 до 8 символів.';
$lang['DirectAdmin.!error.direct_admin_username.format'] = 'Ім\'я користувача може містити лише алфавітно-цифрові символи.';
$lang['DirectAdmin.!error.direct_admin_domain.format'] = 'Будь ласка, введіть дійсне доменне ім\'я виду: domain.com';
$lang['DirectAdmin.!error.meta[ip].empty'] = 'Необхідно вказати IP-адресу.';
$lang['DirectAdmin.!error.meta[package].empty'] = 'Потрібен пакет DirectAdmin.';
$lang['DirectAdmin.!error.meta[type].format'] = 'Тип облікового запису повинен бути або користувачем, або реселлером.';
$lang['DirectAdmin.!error.api.internal'] = 'Сталася внутрішня помилка або сервер не відповів на запит.';
$lang['DirectAdmin.!error.name_servers.count'] = 'Ви повинні визначити принаймні 2 сервери імен.';
$lang['DirectAdmin.!error.name_servers.valid'] = 'Один або декілька введених серверів імен є недійсними.';
$lang['DirectAdmin.!error.account_limit.valid'] = 'Ліміт рахунку має бути залишено порожнім (для необмежених рахунків) або задано цілим числом.';
$lang['DirectAdmin.!error.use_ssl.format'] = 'Використовувати SSL має бути або true, або false.';
$lang['DirectAdmin.!error.password.format'] = 'Ви повинні ввести Пароль.';
$lang['DirectAdmin.!error.user_name.empty'] = 'Ви повинні ввести Ім\'я користувача.';
$lang['DirectAdmin.!error.port.format'] = 'Порт повинен бути числовим.';
$lang['DirectAdmin.!error.host_name.format'] = 'Ім\'я хоста видається недійсним.';
$lang['DirectAdmin.!error.server_name.empty'] = 'Ви повинні ввести мітку сервера.';
$lang['DirectAdmin.name'] = 'DirectAdmin';

==> blesta-5.11.4.zip: blesta/components/modules/direct_admin/language/uk_ua/direct_admin.php <==
<?php
/**
 * Direct Admin
 *
 * @package blesta
 * @subpackage blesta.language.uk_ua
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DirectAdmin.tab_client_actions.field_direct_admin_password'] = 'Пароль';
$lang['DirectAdmin.tab_client_stats.no_results'] = 'Статистична інформація наразі недоступна.';
$lang['DirectAdmin.tab_client_stats.info_heading.value'] = 'Значення';
$lang['DirectAdmin.tab_client_stats.info_heading.field'] = 'Поле';
$lang['DirectAdmin.tab_client_stats.info_title'] = 'Інформація';
$lang['DirectAdmin.tab_client_stats'] = 'Статистика';
$lang['DirectAdmin.edit_row.add_btn'] = 'Сервер редагування';
$lang['DirectAdmin.edit_row.notes_title'] = 'Примітки';
$lang['DirectAdmin.edit_row.remove_name_server'] = 'Видалити';
$lang['DirectAdmin.edit_row.name_server_host_col'] = 'Ім\'я хоста';
$lang['DirectAdmin.edit_row.name_server_col'] = 'Сервер імен';
$lang['DirectAdmin.edit_row.name_server_btn'] = 'Додати додатковий сервер імен';
$lang['DirectAdmin.edit_row.name_servers_title'] = 'Сервери імен';
$lang['DirectAdmin.edit_row.basic_title'] = 'Основні налаштування';
$lang['DirectAdmin.edit_row.box_title'] = 'Редагування сервера DirectAdmin';
$lang['DirectAdmin.add_row.add_btn'] = 'Додати сервер';
$lang['DirectAdmin.add_row.notes_title'] = 'Примітки';
$lang['DirectAdmin.add_row.remove_name_server'] = 'Видалити';
$lang['DirectAdmin.add_row.name_server_host_col'] = 'Ім\'я хоста';
$lang['DirectAdmin.add_row.name_server_col'] = 'Сервер імен';
$lang['DirectAdmin.add_row.name_server_btn'] = 'Додати додатковий сервер імен';
$lang['DirectAdmin.add_row.name_servers_title'] = 'Сервери імен';
$lang['DirectAdmin.add_row.basic_title'] = 'Основні налаштування';
$lang['DirectAdmin.add_row.box_title'] = 'Додати сервер DirectAdmin';
$lang['DirectAdmin.row_meta.name_server'] = 'Сервер імен %1$s';
$lang['DirectAdmin.row_meta.account_limit'] = 'Ліміт рахунку';
$lang['DirectAdmin.row_meta.use_ssl'] = 'Використовуйте SSL при підключенні до API (рекомендовано)';
$lang['DirectAdmin.row_meta.password'] = 'Пароль';
$lang['DirectAdmin.row_meta.user_name'] = 'Ім\'я користувача';
$lang['DirectAdmin.row_meta.default_port'] = '2222';
$lang['DirectAdmin.row_meta.port'] = 'Порт';
$lang['DirectAdmin.row_meta.host_name'] = 'Ім\'я хоста';
$lang['DirectAdmin.row_meta.server_name'] = 'Мітка сервера';
$lang['DirectAdmin.manage.module_groups.confirm_delete'] = 'Ви впевнені, що хочете видалити цю групу серверів?';
$lang['DirectAdmin.manage.module_rows.confirm_delete'] = 'Ви впевнені, що хочете видалити цей сервер?';
$lang['DirectAdmin.manage.module_groups.delete'] = 'Видалити';
$lang['DirectAdmin.manage.module_rows.delete'] = 'Видалити';
$lang['DirectAdmin.manage.module_groups.edit'] = 'Редагувати';
$lang['DirectAdmin.manage.module_rows.edit'] = 'Редагувати';
$lang['DirectAdmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['DirectAdmin.manage.module_groups_heading.options'] = 'Параметри';
$lang['DirectAdmin.manage.module_groups_heading.servers'] = 'Кількість серверів';
$lang['DirectAdmin.manage.module_groups_heading.name'] = 'Назва групи';
$lang['DirectAdmin.manage.module_rows_heading.options'] = 'Параметри';
$lang['DirectAdmin.manage.module_rows_heading.accounts'] = 'Рахунки';
$lang['DirectAdmin.manage.module_rows_heading.host_name'] = 'Ім\'я хоста';
$lang['DirectAdmin.manage.module_rows_heading.name'] = 'Мітка сервера';
$lang['DirectAdmin.manage.module_groups_title'] = 'Групи серверів';
$lang['DirectAdmin.manage.module_rows_title'] = 'Сервери';
$lang['DirectAdmin.add_module_group'] = 'Додати групу серверів';
$lang['DirectAdmin.add_module_row'] = 'Додати сервер';
$lang['DirectAdmin.package_fields.ip_assign'] = 'Призначити';
$lang['DirectAdmin.package_fields.ip_shared'] = 'Спільне';
$lang['DirectAdmin.package_fields.ip'] = 'IP-адреса';
$lang['DirectAdmin.package_fields.package'] = 'Пакет DirectAdmin';
$lang['DirectAdmin.package_fields.type_reseller'] = 'Посередник';
$lang['DirectAdmin.package_fields.type_user'] = 'Користувач';
$lang['DirectAdmin.package_fields.type'] = 'Тип рахунку';
$lang['DirectAdmin.service_info.option_login'] = 'Увійдіть в систему';
$lang['DirectAdmin.service_info.options'] = 'Параметри';
$lang['DirectAdmin.service_info.server'] = 'Сервер';
$lang['DirectAdmin.service_info.password'] = 'Пароль';
$lang['DirectAdmin.service_info.username'] = 'Ім\'я користувача';
$lang['DirectAdmin.tab_client_actions.text_generate_password'] = 'Згенерувати пароль';
$lang['DirectAdmin.tab_client_actions.field_password_submit'] = 'Оновити пароль';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_confirm_password'] = 'Підтвердити пароль';
$lang['DirectAdmin.tab_client_actions.change_password'] = 'Змінити пароль';
$lang['DirectAdmin.service_field.text_generate_password'] = 'Згенерувати пароль';
$lang['DirectAdmin.service_field.email'] = 'Електронна пошта';
$lang['DirectAdmin.service_field.password'] = 'Пароль';
$lang['DirectAdmin.service_field.username'] = 'Ім\'я користувача';
$lang['DirectAdmin.service_field.domain'] = 'Домен';
$lang['DirectAdmin.server_groups.no_results'] = 'Груп серверів не існує.';
$lang['DirectAdmin.servers.no_results'] = 'Серверів немає.';
$lang['DirectAdmin.order_options.roundrobin'] = 'Рівномірний розподіл між серверами';
$lang['DirectAdmin.order_options.first'] = 'Перший неповний сервер';
$lang['DirectAdmin.tab_client_actions'] = 'Дії';
$lang['DirectAdmin.tab_stats'] = 'Статистика';
$lang['DirectAdmin.module_group'] = 'Група серверів';
$lang['DirectAdmin.module_row_plural'] = 'Сервери';
$lang['DirectAdmin.module_row'] = 'Сервер';
$lang['DirectAdmin.description'] = 'DirectAdmin - це графічна веб-панель керування хостингом, призначена для полегшення адміністрування веб-сайтів.';
$lang['DirectAdmin.!error.change_package.type'] = 'Модуль не підтримує перемикання між пакетами користувача та реселера.';
$lang['DirectAdmin.!error.direct_admin_email.format'] = 'Будь ласка, введіть дійсну адресу електронної пошти.';
$lang['DirectAdmin.!error.direct_admin_password.matches'] = 'Пароль і Підтвердити пароль не збігаються.';
$lang['DirectAdmin.!error.direct_admin_password.format'] = 'Переконайтеся, що пароль містить наступне: Щонайменше 12 символів, щонайменше 1 символ верхнього регістру A-Z, щонайменше 1 символ нижнього регістру a-z, щонайменше 1 цифру 0-9 та щонайменше 1 спеціальний символ з набору: !"#$%&\'()*+,-./:;<=>?@[]^_` {|}';
$lang['DirectAdmin.!error.direct_admin_username.length'] = 'Ім\'я користувача повинно мати довжину від 4 до 8 символів.';
$lang['DirectAdmin.!error.direct_admin_username.format'] = 'Ім\'я користувача може містити лише алфавітно-цифрові символи.';
$lang['DirectAdmin.!error.direct_admin_domain.format'] = 'Будь ласка, введіть дійсне доменне ім\'я виду: domain.com';
$lang['DirectAdmin.!error.meta[ip].empty'] = 'Необхідно вказати IP-адресу.';
$lang['DirectAdmin.!error.meta[package].empty'] = 'Потрібен пакет DirectAdmin.';
$lang['DirectAdmin.!error.meta[type].format'] = 'Тип облікового запису повинен бути або користувачем, або реселлером.';
$lang['DirectAdmin.!error.api.internal'] = 'Сталася внутрішня помилка або сервер не відповів на запит.';
$lang['DirectAdmin.!error.name_servers.count'] = 'Ви повинні визначити принаймні 2 сервери імен.';
$lang['DirectAdmin.!error.name_servers.valid'] = 'Один або декілька введених серверів імен є недійсними.';
$lang['DirectAdmin.!error.account_limit.valid'] = 'Ліміт рахунку має бути залишено порожнім (для необмежених рахунків) або задано цілим числом.';
$lang['DirectAdmin.!error.use_ssl.format'] = 'Використовувати SSL має бути або true, або false.';
$lang['DirectAdmin.!error.password.format'] = 'Ви повинні ввести Пароль.';
$lang['DirectAdmin.!error.user_name.empty'] = 'Ви повинні ввести Ім\'я користувача.';
$lang['DirectAdmin.!error.port.format'] = 'Порт повинен бути числовим.';
$lang['DirectAdmin.!error.host_name.format'] = 'Ім\'я хоста видається недійсним.';
$lang['DirectAdmin.!error.server_name.empty'] = 'Ви повинні ввести мітку сервера.';
$lang['DirectAdmin.name'] = 'DirectAdmin';
$lang['DirectAdmin.row_meta.ip_address'] = 'IP-адреса';
$lang['DirectAdmin.!error.ip_address.format'] = 'Здається, IP-адреса є недійсною.';
